#!/bin/bash
set -euo pipefail
IFS=$'\n\t'

VERSION_PREFIX="2:"
VERSION_SUFFIX="tux1"

export DEBEMAIL="tux@tuxedocomputers.com"
export DEBFULLNAME="TUXEDO Computers"

git config --global user.email "tux@tuxedocomputers.com"
git config --global user.name "TUXEDO Computers"


UPSTREAM_RELEASES_URL="https://ftp.mozilla.org/pub/firefox/releases/"
UPSTREAM_VERSION=$( curl -s "$UPSTREAM_RELEASES_URL" | \
                    grep -v 0b | \
                    grep -Eo '[0-9]+[0-9]+[0-9]+\.[0-9]+\.[0-9]|[0-9]+[0-9]+[0-9]+\.[0-9]' | \
                    sort --unique -rV | \
                    head -n1)
VERSION="${VERSION_PREFIX}${UPSTREAM_VERSION}~${VERSION_SUFFIX}"

CURRENT_CHANGELOG_VERSION=$(dpkg-parsechangelog --file debian/changelog --show-field Version)

if [ "$CURRENT_CHANGELOG_VERSION" = "$VERSION" ]; then
    echo "No new Version"
    exit 0
fi

COMMIT_MESSAGE="new upstream version - ${UPSTREAM_VERSION}"


git checkout "${CI_COMMIT_BRANCH}"

dch --newversion "${VERSION}" "${COMMIT_MESSAGE}"
dch --release "${COMMIT_MESSAGE}"

git add debian/changelog

git commit --message "${COMMIT_MESSAGE}"

gpg --import ${TUXEDO_BOT_GPG_PRIVATE_KEY}

git push --force --progress --verbose "https://${TUXEDO_BOT_GITLAB_USERNAME}:${TUXEDO_BOT_GITLAB_CI_PERSONAL_ACCESS_TOKEN}@${CI_REPOSITORY_URL#*@}" ${CI_COMMIT_BRANCH}

